@@ -3,11 +3,10 @@
 
 import os
 import sys
+from bottle import request, response
 from Cookie import SimpleCookie
 from session import Session
 from session import ExpressSession
-from logger import Log
-from config import Config
 
 
 class Dispatcher(object):
@@ -114,13 +113,13 @@ class SessionWsgi(object):
         self.app = wsgi
 
     def wsgi(self, environ, start_response):
+        return self.app
+
+    def __call__(self, environ, start_response):
         sc = SimpleCookie()
         if 'HTTP_COOKIE' in environ:
             sc.load(environ.get('HTTP_COOKIE'))
         ses = Session(ExpressSession(sc))
         ses.read()
         environ['express.session'] = ses
-        return self.app
-
-    def __call__(self, environ, start_response):
-        return self.wsgi(environ, start_response)(environ, start_response)
+        return self.app(environ, start_response)
\ No newline at end of file
