@@ -2,22 +2,22 @@
 # -*- coding: utf-8 -*-
 
 import os
-import sys
-import json
-import traceback
-import gettext
 import re
+import json
+import gettext
+import traceback
+from bottle import request
 from functools import wraps
 from jinja2 import BaseLoader
 from jinja2 import Environment
 from jinja2 import ChoiceLoader
 from jinja2 import FileSystemLoader
 from jinja2 import TemplateNotFound
-from bottle import request, response, PluginError, hook
+from bottle import request, response, PluginError
 from .logger import Log
 from .config import Config
-from .session import Session
 from .errors import BaseError, ValidationError, ConnectionError
+
 # Format of http.request.header.Accept-Language.
 # refs: http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4
 REQUEST_ACCEPT_LANGUAGE_RE = re.compile(r'''
@@ -198,7 +198,7 @@ class Jinja2i18nPlugin(Jinja2Plugin):
             trans.install(True)
             self.app._ = trans.ugettext
             self.prepared[prepared_key] = trans
-        except Exception as e:
+        except Exception:
             Log.get_instance().error("No locale folder found for translations or problems with importing it.")
             trans = None
             self.app._ = lambda s: s
@@ -295,3 +295,28 @@ class JsonPlugin(object):
 
     def close(self):
         pass
+
+
+class SessionPlugin(object):
+    name = 'session'
+    api = 2
+
+    def __init__(self):
+        pass
+
+    def apply(self, callback, route):
+        @wraps(callback)
+        def wrapper(*args, **kwargs):
+            if self.name in route.skiplist:
+                return callback(*args, **kwargs)
+            data = callback(*args, **kwargs)
+            if 'express.session' in request.environ:
+                request.environ['express.session'].write()
+            return data
+        return wrapper
+
+    def setup(self, app):
+        pass
+
+    def close(self):
+        pass
