@@ -2,7 +2,6 @@
 # -*- coding: utf-8 -*-
 
 import time
-import json
 import uuid
 import urllib
 import calendar
@@ -13,7 +12,6 @@ from .logger import Log
 from .crypt import Crypt
 from .store import Redis
 from .config import Config
-from .singleton import Singleton
 
 
 class Session(object):
@@ -152,6 +150,7 @@ class ExpressSession(SessionAbstract):
                         self.data = {}
                         for key in self.cookie:
                             self.cookie[key] = None
+
         except Exception as e:
             print("Error while reading session: {0}".format(e))
             self.log.error("Error while reading session: {0}".format(e))
@@ -212,8 +211,8 @@ class ExpressSession(SessionAbstract):
             self.data, object_hook=phpserialize.phpobject)
         self.redis.set(self.cookie['session_id'], data)
         self.redis.expire(self.cookie['session_id'], max_age)
-        response.set_cookie(self.name, self.crypt.encrypt(
-            phpserialize.dumps(self.cookie)), **params)
+        response.set_cookie(self.name, urllib.quote_plus(
+            self.crypt.encrypt(phpserialize.dumps(self.cookie))), **params)
 
     def __str__(self):
         return ':'.join([self.cookie['session_id'] if self.cookie['session_id'] else '', self.data.__str__()])
